@@ -1,6 +1,3 @@
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import warnings
 
 from pgspecial.namedqueries import NamedQueries
@@ -36,6 +33,7 @@ from prompt_toolkit.enums import DEFAULT_BUFFER, EditingMode
 from prompt_toolkit.shortcuts import PromptSession, CompleteStyle
 from prompt_toolkit.document import Document
 from prompt_toolkit.filters import HasFocus, IsDone
+from prompt_toolkit.formatted_text import ANSI
 from prompt_toolkit.lexers import PygmentsLexer
 from prompt_toolkit.layout.processors import (
     ConditionalProcessor,
@@ -62,8 +60,6 @@ from .config import (
     get_config,
 )
 from .key_bindings import pgcli_bindings
-from .encodingutils import utf8tounicode
-from .encodingutils import text_type
 from .packages.prompt_utils import confirm_destructive_query
 from .__init__ import __version__
 
@@ -362,7 +358,7 @@ class PGCli(object):
                     user=user,
                     host=host,
                     port=port,
-                    **self.pgexecute.extra_args
+                    **self.pgexecute.extra_args,
                 )
             except OperationalError as e:
                 click.secho(str(e), err=True, fg="red")
@@ -537,7 +533,7 @@ class PGCli(object):
             # fails. Don't prompt if the -w flag is supplied
             if self.never_passwd_prompt:
                 return False
-            error_msg = utf8tounicode(exc.args[0])
+            error_msg = exc.args[0]
             if "no password supplied" in error_msg:
                 return True
             if "password authentication failed" in error_msg:
@@ -776,7 +772,8 @@ class PGCli(object):
             ):
                 prompt = self.get_prompt("\\d> ")
 
-            return [("class:prompt", prompt)]
+            prompt = prompt.replace("\\x1b", "\x1b")
+            return ANSI(prompt)
 
         def get_continuation(width, line_number, is_soft_wrap):
             continuation = self.multiline_continuation_char * (width - 1) + " "
@@ -1256,7 +1253,7 @@ def cli(
     if list_databases:
         database = "postgres"
 
-    if dsn is not "":
+    if dsn != "":
         try:
             cfg = load_config(pgclirc, config_full_path)
             dsn_config = cfg["alias_dsn"][dsn]
@@ -1363,7 +1360,7 @@ def is_select(status):
 
 
 def exception_formatter(e):
-    return click.style(utf8tounicode(str(e)), fg="red")
+    return click.style(str(e), fg="red")
 
 
 def format_output(title, cur, headers, status, settings):
@@ -1379,7 +1376,7 @@ def format_output(title, cur, headers, status, settings):
             return settings.missingval
         if not isinstance(val, list):
             return val
-        return "{" + ",".join(text_type(format_array(e)) for e in val) + "}"
+        return "{" + ",".join(str(format_array(e)) for e in val) + "}"
 
     def format_arrays(data, headers, **_):
         data = list(data)
@@ -1409,7 +1406,7 @@ def format_output(title, cur, headers, status, settings):
         output.append(title)
 
     if cur:
-        headers = [case_function(utf8tounicode(x)) for x in headers]
+        headers = [case_function(x) for x in headers]
         if max_width is not None:
             cur = list(cur)
         column_types = None
@@ -1427,10 +1424,10 @@ def format_output(title, cur, headers, status, settings):
                 ):
                     column_types.append(int)
                 else:
-                    column_types.append(text_type)
+                    column_types.append(str)
 
         formatted = formatter.format_output(cur, headers, **output_kwargs)
-        if isinstance(formatted, (text_type)):
+        if isinstance(formatted, str):
             formatted = iter(formatted.splitlines())
         first_line = next(formatted)
         formatted = itertools.chain([first_line], formatted)
@@ -1438,7 +1435,7 @@ def format_output(title, cur, headers, status, settings):
             formatted = formatter.format_output(
                 cur, headers, format_name="vertical", column_types=None, **output_kwargs
             )
-            if isinstance(formatted, (text_type)):
+            if isinstance(formatted, str):
                 formatted = iter(formatted.splitlines())
 
         output = itertools.chain(output, formatted)
