@@ -1,11 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 Steps for behavioral style tests are defined in this module.
 Each step is defined by the string decorating it.
 This string is used to call the step in "*.feature" file.
 """
-from __future__ import unicode_literals, print_function
-
 import pexpect
 
 from behave import when, then
